@@ -174,8 +174,12 @@ double _grid_search(Matrix<double,Row>& X, Matrix<double,Row>& Y, vector<double>
 // assume last col of X is chngptvar, which will be updated as move through the grid
 // thresholdIdx are 1-based index, which define the grid of thresholds
 // For grid, the meaning of the first two variables are B and r instead 
-SEXP gridC_gaussian(SEXP u_X, SEXP u_Y, SEXP u_W, SEXP u_wAllOne, 
-     SEXP u_thresholdIdx, SEXP u_nBoot, SEXP u_isUpperHinge)
+SEXP gridC_gaussian(
+     SEXP u_X, SEXP u_Y, 
+     SEXP u_W, SEXP u_wAllOne, 
+     SEXP u_thresholdIdx, SEXP u_skipping,
+     SEXP u_nBoot, 
+     SEXP u_isUpperHinge)
 {
     double* X_dat = REAL(u_X);
     double* Y_dat=REAL(u_Y); 
